dispMUA.arDispMUAAllocation["f"] =
{
  "firewall notification system" : [ "astaro.png" , "http://www.astaro.de/" ] ,
  "flicks softwares ocxmail" : [ "ocxmail.png" , "http://www.flicks.com/prod.htm#ocxmail" ] ,
  "fbm communication server" : [ "feedbackmanager.png" , "http://www.feedbackmanager.de/" ] ,
  "futureshop mail system" : [ "futurespirits.png" , "http://www.future-s.com/" ] ,
  "fr3ddie's forte agent" : [ "fr3ddie.png" , "http://www.fr3ddie.it/software/software.html" ] ,
  "first-coffee mailer" : [ "first-coffee.png" , "http://www.first-coffee.com/" ] ,
  "falks perl mailer" : [ "bike24_net.png" , "http://www.bike24.net/" ] ,
  "funmail2u-mailer" : [ "funmail2u.png" , "http://www.funmail2u.de/" ] ,
  "forte free agent" : [ "forte_agent.png" , "http://www.forteinc.com/" ] ,
  "freemail.ukr.net" : [ "ukr_net.png" , "http://www.ukr.net/" ] ,
  "flexist mailer" : [ "flexist_de.png" , "http://www.flexist.de/" ] ,
  "frontdoor apx" : [ "frontdoor-apx.png" , "http://www.defsol.se/iapxw.html" ] ,
  "friend mailer" : [ "friend-mailer.png" , "http://www.ava-soft.com/products/fm/" ] ,
  "freecity gmbh" : [ "freecity.png" , "http://webmail.freecity.de/" ] ,
  "fuzzy admail" : [ "fuzzy_admail.png" , "http://www.fuzzy.com.br/" ] ,
  "fuman mailer" : [ "future-management.png" , "http://www.continue.de/" ] ,
  "freemails.ch" : [ "freemails_ch.png" , "http://www.freemails.ch/" ] ,
  "fotka mailer" : [ "fotka.png" , "http://www.fotka.pl/" ] ,
  "finalbuilder" : [ "finalbuilder_com.png" , "http://www.finalbuilder.com/" ] ,
  "fronter.com" : [ "fronter.png" , "http://fronter.info/com/" ] ,
  "freemail.gr" : [ "freemail_gr.png" , "http://www.freemail.gr/" ] ,
  "form e-mail" : [ "form-email.png" , "http://www.patshaping.de/projekte/form-email/" ] ,
  "forte-agent" : [ "forte_agent.png" , "http://www.forteinc.com/" ] ,
  "forte agent" : [ "forte_agent.png" , "http://www.forteinc.com/" ] ,
  "fx-service" : [ "fx-service.png" ] ,
  "ftk mailer" : [ "ftk-mailer.png" , "http://www.fotokasten.de/" ] ,
  "fromwap.ru" : [ "fromwap_ru.png" , "http://www.fromwap.ru/" ] ,
  "freeweb.hu" : [ "freeweb_hu.png" , "http://freeweb.hu/" ] ,
  "forteagent" : [ "forte_agent.png" , "http://www.forteinc.com/" ] ,
  "formmailer" : [ "formmailer.png" , "http://www.formmailer.com/" ] ,
  "firstclass" : [ "firstclass.png" , "http://www.firstclass.com/" ] ,
  "felamimail" : [ "felamimail.png" , "http://www.phpgroupware.org/" ] ,
  "futurelab" : [ "futurelab.png" , "http://www.futurelab.com/" ] ,
  "fotovista" : [ "fotovista_com.png" , "http://www.fotovista.com/" ] ,
  "feedblitz" : [ "feedblitz.png" , "http://www.feedblitz.com/" ] ,
  "fusemail" : [ "fusemail.png" , "http://www.fusemail.com/" ] ,
  "fudforum" : [ "fudforum.png" , "http://fudforum.org/forum/" ] ,
  "fotexnet" : [ "fotexnet_hu.png" , "http://www.fotexnet.hu/" ] ,
  "flyspray" : [ "flyspray.png" , "http://flyspray.org/" ] ,
  "flexmail" : [ "flexmail.png" , "http://www.pocketinformant.com/products_info.php?p_id=mail" ] ,
  "fletmail" : [ "fletmail.png" , "http://www.pancho.dk/fletmail/" ] ,
  "fishbowl" : [ "fishbowl.png" , "http://www.fishbowl.com/" ] ,
  "firepass" : [ "f5.png" , "http://www.f5.com/products/firepass/" ] ,
  "favo.org" : [ "favo_org.png" , "http://www.favo.org/" ] ,
  "fastmomi" : [ "fastweb_it.png" , "http://www.fastweb.it/" ] ,
  "fastmail" : [ "fastmail.png" , "http://www.fastmail.fm/" ] ,
  "f5mailer" : [ "f5mailer.png" ] ,
  "famailer" : [ "famailer.png" , "http://www.faprojects.de/" ] ,
  "frnl.de" : [ "frnl_de.png" , "http://www.flatrate-newsletter.de/" ] ,
  "freenet" : [ "freenet.png" , "http://mail.freenet.de/" ] ,
  "foxmail" : [ "foxmail.png" , "http://www.foxmail4u.de/" ] ,
  "forumup" : [ "forumup.png" , "http://www.forumup.com/" ] ,
  "formgen" : [ "formgen.png" , "http://www.formgen.de/" ] ,
  "forcast" : [ "forcast.png" , "http://www.forcast.jp/" ] ,
  "firefox" : [ "firefox.png" , "http://www.mozilla.com/firefox/" ] ,
  "farmail" : [ "farmail.png" , "http://trexinc.sourceforge.net/farmail.php" ] ,
  "freexp" : [ "crosspoint_freexp.png" , "http://www.freexp.de/" ] ,
  "frappr" : [ "frappr.png" , "http://www.frappr.com/" ] ,
  "fluxbb" : [ "fluxbb.png" , "http://fluxbb.org/" ] ,
  "fastit" : [ "fastit.png" , "http://www.fastit.net/" ] ,
  "factux" : [ "factux.png" , "http://www.factux.org/" ] ,
  "flip" : [ "flip.png" , "http://www.flipdev.org/" ] ,
  "fcms" : [ "fcms.png" , "http://www.fidion.de/" ] ,
}
